@@ -30,7 +30,7 @@ APPLET_NAME = "firewall-applet"
 DATADIR = "/usr/share/" + DAEMON_NAME
 CONFIG_GLADE_NAME = CONFIG_NAME + ".glade"
 COPYRIGHT = "(C) 2010-2017 Red Hat, Inc."
-VERSION = "2.3.1"
+VERSION = "2.4.0"
 AUTHORS = [
     "Thomas Woerner <twoerner@redhat.com>",
     "Jiri Popelka <jpopelka@redhat.com>",
@@ -97,15 +97,15 @@ SYSCTL_CONFIG = "/etc/sysctl.conf"
 
 # commands used by backends
 COMMANDS = {
-    "ipv4": "/usr/bin/iptables",
-    "ipv4-restore": "/usr/bin/iptables-restore",
-    "ipv6": "/usr/bin/ip6tables",
-    "ipv6-restore": "/usr/bin/ip6tables-restore",
-    "eb": "/usr/bin/ebtables",
-    "eb-restore": "/usr/bin/ebtables-restore",
-    "ipset": "/bin/false",
-    "modprobe": "/usr/bin/modprobe",
-    "rmmod": "/usr/bin/rmmod",
+    "ipv4": "/sbin/iptables",
+    "ipv4-restore": "/sbin/iptables-restore",
+    "ipv6": "/sbin/ip6tables",
+    "ipv6-restore": "/sbin/ip6tables-restore",
+    "eb": "/sbin/ebtables",
+    "eb-restore": "/sbin/ebtables-restore",
+    "ipset": "/usr/sbin/ipset",
+    "modprobe": "/sbin/modprobe",
+    "rmmod": "/sbin/rmmod",
 }
 
 LOG_DENIED_VALUES = ["all", "unicast", "broadcast", "multicast", "off"]
